@@ -77,3 +77,7 @@ class Payment:
         response = r.json()
         response['results'] = [_format(r) for r in response['results']]
         return ok(response)
+
+    def get_payment_methods(self):
+        r = requests.get(self.url + '/payment-methods/1',headers=self.headers)
+        return r.json()
\ No newline at end of file
