@@ -3,7 +3,7 @@ from .Customer import Customer
 from .Card import Card
 from .CardToken import CardToken
 from .Payment import Payment
-
+from .Refund import Refund
 
 class MercadoPagoSDK:
     def __init__(self, merchant, marketplace=False):
@@ -29,3 +29,6 @@ class MercadoPagoSDK:
     
     def payment(self):
         return Payment(self.sdk)
+
+    def refund(self):
+        return Refund(self.sdk)
